Instances
=========

.. currentmodule:: pykeen.triples

.. autoclass:: Instances
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~Instances.from_triples
      ~Instances.get_collator

   .. rubric:: Methods Documentation

   .. automethod:: from_triples
   .. automethod:: get_collator
